from setuptools import setup
setup(

    name    =	'pytelnetMK',

    version =	'0.0.1',

    python_requires ='>=3',

    py_modules	=   ['pytelnetMK'],

    author  =	'pklarner',

    author_email    =	'pedro@preciseipostei.com.br',

    url	=   'http://www.preciseipostei.com.br',

    install_requires=['telnetlib3 >=1.0.0'],

    description	=   'Connect Mikrotik telnet server using Telnetlib ',
    
    )





